@@ -19,10 +19,10 @@ def api_encode(value):
     """
     Encodes a native Python value in a way that the API expects. Encodes lists
     and dicts to JSON and boolean values to 'true' or 'false'.
-    
+
     Args:
         value - The Python value to encode.
-    
+
     Returns:
         The value encoded for the Janrain API.
     """
@@ -31,47 +31,48 @@ def api_encode(value):
     elif type(value) == bool:
         return str(value).lower()
     return value
-   
+
 class Api(object):
     """
-    Base object for making API calls to the Janrain API. 
-    
+    Base object for making API calls to the Janrain API.
+
     Args:
         api_url  - Absolute URL to API.
         defaults - A dictionary of default parameters to pass to every API call.
-    
+
     Example:
         defaults = {'client_id': "...", 'client_secret': "..."}
         api = janrain.capture.Api("https://...", defaults)
         count = api.call("entity.count", type_name="user")
     """
-    def __init__(self, api_url, defaults=None):
+    def __init__(self, api_url, defaults={}):
         self.logger = logging.getLogger(__name__)
         if api_url[0:4] == "http":
             self.api_url = api_url
         else:
             self.api_url = "https://" + api_url
         self.defaults = defaults
-    
+        self.sign_requests = True
+
     def call(self, api_call, **kwargs):
         """
-        Low-level method for making API calls. It handles encoding the 
+        Low-level method for making API calls. It handles encoding the
         parameters, constructing authentication headers, decoding the response,
         and converting API error responses into Python exceptions.
-        
+
         Args:
             api_call - The API endpoint as a relative URL.
-        
+
         Keyword Args:
             Keyword arguments are specific to the api_call and can be found in
             the Janrain API documentation at:
             http://developers.janrain.com/documentation/capture/restful_api/
-        
+
         Raises:
             InvalidApiCallError, ApiResponseError
         """
         # Encode values for the API (JSON, bools, nulls)
-        params = dict((key, api_encode(value)) 
+        params = dict((key, api_encode(value))
             for key, value in kwargs.iteritems() if value is not None)
         params.update(self.defaults)
 
@@ -81,11 +82,12 @@ class Api(object):
         self.logger.debug(url)
 
         # Signing the request modifies the request object and params in-place.
-        # Sign the request *before* encoding and passing the params.       
+        # Sign the request *before* encoding and passing the params.
         request = Request(url)
-        self.sign_request(request, api_call, params)
+        if self.sign_requests:
+            self.sign_request(request, api_call, params)
         request.add_data(urlencode(params))
-        
+
         try:
             with closing(urlopen(request)) as response:
                 body = response.read()
@@ -103,23 +105,23 @@ class Api(object):
                 raise error
 
         return self.parse_response(body)
-        
+
     def parse_response(self, response):
         """
         Parse the response from the API, decoding the JSON and converting errors
         into exceptions.
-        
+
         Args:
             response - The JSON response from the Janrain API.
-        
+
         Returns:
             The response from the API decoded into Python native types.
-        
+
         Raises:
             ApiResponseError
         """
         data = json_decode(response)
-        
+
         if data['stat'] == 'error':
             self.logger.debug("Response:\n" + json_encode(data, indent=4))
             try:
@@ -128,24 +130,24 @@ class Api(object):
                 message = data['message']
             raise ApiResponseError(data['code'], data['error'], message, data)
         return data
-        
+
     def sign_request(self, request, api_call, params):
         """
         Sign the API call by generating an "Authentication" header. This method
         will add headers to the request object and remove auth_token, client_id,
         and client_secret from the parameters if they exist.
-        
+
         Args:
             request  - A urllib2.Request instance.
-            api_call - The API endpoint as a relative URL. 
+            api_call - The API endpoint as a relative URL.
             params   - A dictionary of parameters in the POST to the API.
         """
-        # Do not POST authentication parameters. Use them to create an 
+        # Do not POST authentication parameters. Use them to create an
         # authentication header instead.
         access_token = params.pop('access_token', None)
         client_id = params.pop('client_id', None)
         client_secret = params.pop('client_secret', None)
-        
+
         self.logger.debug(params)
 
         # create the authorization header
@@ -161,6 +163,6 @@ class Api(object):
             sha1_str = hmac.new(client_secret, data, sha1).digest()
             hash_str = b64encode(sha1_str)
             request.add_header("Date", timestamp)
-            request.add_header("Authorization", 
+            request.add_header("Authorization",
                                "Signature {}:{}".format(client_id, hash_str))
-                           
+
